pub async fn execute_enhanced_update() -> Result<(bool, Vec<(String, bool, String)>)>Expand description
Execute update/install for AI CLI tools
If tool_name is None, update all installed tools If tool_name is Some, update/install that specific tool Enhanced update function that updates both AIW and AI CLI tools